@@ -1,6 +1,6 @@
 /*
  *  Copyright 2014  Andreas Xavier <andxav at zoho dot com>
- *  Copyright 2014  Inge Wallin
+ *  Copyright 2014  Inge Wallin <inge@lysator.liu.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -97,7 +97,7 @@ void StatisticsLegendWidget::paintEvent(QPaintEvent *)
     paintColorBar(painter, rect, wordCount, colors);
 
     // Draw the legend texts
-    painter.setPen(Qt::black);
+    painter.setPen(QPalette().color(QPalette::WindowText));
     painter.drawText(leftRect, Qt::AlignRight | Qt::AlignVCenter, leftString);
     painter.drawText(rightRect, Qt::AlignLeft | Qt::AlignVCenter, rightString);
 }
